@@ -5,7 +5,7 @@ use strict;
 use warnings;
 no autovivification;
 
-use version; our $VERSION = qv('v1.2.0');
+use version; our $VERSION = qv('v1.4.0');
 
 
 use Time::HiRes                              qw( );
@@ -334,7 +334,7 @@ sub _projects {
    for my $field_name (
       'category',           # Category's "id", "slug" or "name".
       'location',           # Location as a "Where on Earth Identifier" ("WOEID")
-      'sort',               # 'magic' (default), 'end_date', 'launch_date', 'popularity', 'most_funded'
+      'sort',               # 'magic' (default), 'end_date', 'newest', 'launch_date', 'popularity', 'most_funded'
       'q',                  # Search terms
       'backed_by_self',     # Boolean
       'starred_by_self',    # Boolean
@@ -359,8 +359,8 @@ sub _projects {
    $form{raised}   = 'all'   if !defined($form{raised})      || !length($form{raised});
    $form{tag}      = ''      if !defined($form{tag});
 
-   $form{sort} =~ /^(?:magic|end_date|launch_date|popularity|most_funded)\z/
-      or my_croak(400, "Unrecognized value for sort. Valid: magic, end_date, launch_date, popularity, most_funded");
+   $form{sort} =~ /^(?:magic|end_date|newest|launch_date|popularity|most_funded)\z/
+      or my_croak(400, "Unrecognized value for sort. Valid: magic, end_date, newest, launch_date, popularity, most_funded");
    $form{state} =~ /^(?:all|live|successful)\z/
       or my_croak(400, "Unrecognized value for state. Valid: all, live, successful");
    $form{pledged} =~ /^(?:all|[0123])\z/
@@ -483,7 +483,7 @@ sub projects_ending_soon {
 
 sub projects_recently_launched {
    my $self = shift;
-   return $self->_projects({ state => 'live', sort => 'launch_date' }, @_);
+   return $self->_projects({ state => 'live', sort => 'newest' }, @_);
 }
 
 sub popular_projects {
@@ -534,7 +534,7 @@ WWW::Kickstarter - Retrieve information from Kickstarter
 
 =head1 VERSION
 
-Version 1.2.0
+Version 1.4.0
 
 
 =head1 SYNOPSIS
@@ -749,6 +749,8 @@ Limits the projects returned to those associated with the specified location.
 
 =item * C<< sort => 'end_date' >>
 
+=item * C<< sort => 'newest' >>
+
 =item * C<< sort => 'launch_date' >>
 
 =item * C<< sort => 'popularity' >>
@@ -843,18 +845,22 @@ I don't know of an API endpoint that returns a list of available tags. The follo
 
 =over
 
-=item * Arctic (id: 39, slug: arctic)
-
 =item * Bikes (id: 50, slug: bikes)
 
+=item * Burning Man (id: 34, slug: burning-man)
+
 =item * Cats (id: 31, slug: cats)
 
 =item * Civic (id: 3, slug: civic)
 
 =item * Cthulhu (id: 38, slug: cthulhu)
 
+=item * Fringe (id: 99, slug: fringe)
+
 =item * Library (id: 46, slug: library)
 
+=item * LOL (id: 105, slug: lol)
+
 =item * Maps (id: 48, slug: maps)
 
 =item * Movie Theater (id: 43, slug: movie-theater)
@@ -865,17 +871,33 @@ I don't know of an API endpoint that returns a list of available tags. The follo
 
 =item * Robots (id: 41, slug: robots)
 
-=item * RPG (id: 33, slug: rpg)
-
 =item * Science (id: 19, slug: science)
 
+=item * Space is the Place (id: 107, slug: space-is-the-place)
+
+=item * World Maker Faire 2014 (id: 106, slug: world-maker-faire-2014)
+
+=back
+
+The following are also tags that are known to exist, but these aren't shown on the website. It's possible they aren't actively used anymore.
+
+=over
+
+=item * Arctic (id: 39, slug: arctic)
+
+=item * Maker Faire (id: 87, slug: maker-faire)
+
+=item * RPG (id: 33, slug: rpg)
+
 =item * Space (id: 28, slug: space)
 
+=item * Sundance (id: 29, slug: sundance)
+
 =item * Zombies (id: 30, slug: zombies)
 
 =back
 
-This list was obtained from L<Kickstarter's Advanced Discover page|https://www.kickstarter.com/discover/advanced>.
+The first list was obtained from L<Kickstarter's Advanced Discover page|https://www.kickstarter.com/discover/advanced>. The second list was obtained through trial and error.
 
 =back
 
@@ -901,7 +923,7 @@ It accepts the same options as L<C<projects>|/projects>.
 
    my $projects_iter = $ks->projects_recently_launched(%opts);
 
-Returns an L<iterator|WWW::Kickstarter::Iterator> that fetches and returns recently launched projects as L<WWW::Kickstarter::Data::Project> objects. The recently launched project is returned first.
+Returns an L<iterator|WWW::Kickstarter::Iterator> that fetches and returns recently launched projects as L<WWW::Kickstarter::Data::Project> objects. The most recently launched project is returned first.
 
 It accepts the same options as L<C<projects>|/projects>.
 
